@@ -19,10 +19,11 @@ __all__ = [
 ]
 
 __name__ = 'python-statsd'
-__version__ = '1.5.7'
+__version__ = '1.5.8'
 __author__ = 'Rick van Hattem'
 __author_email__ = 'Rick.van.Hattem@Fawo.nl'
-__description__ = ('''statsd is a client for Etsy's node-js statsd server. '''
+__description__ = (
+    '''statsd is a client for Etsy's node-js statsd server. '''
     '''A proxy for the Graphite stats collection and graphing server.''')
-__url__ ='https://github.com/WoLpH/python-statsd'
+__url__ = 'https://github.com/WoLpH/python-statsd'
 
