@@ -13,12 +13,16 @@ class Connection(object):
     '''
 
     default_host = 'localhost'
+
     default_port = 8125
+
     default_sample_rate = 1
+
     default_disabled = False
 
     @classmethod
-    def set_defaults(cls, host='localhost', port=8125, sample_rate=1, disabled=False):
+    def set_defaults(
+            cls, host='localhost', port=8125, sample_rate=1, disabled=False):
         cls.default_host = host
         cls.default_port = port
         cls.default_sample_rate = sample_rate
@@ -29,10 +33,12 @@ class Connection(object):
         self._port = int(port or self.default_port)
         self._sample_rate = sample_rate or self.default_sample_rate
         self._disabled = disabled or self.default_disabled
-        self.logger = logging.getLogger('%s.%s'
-            % (__name__, self.__class__.__name__))
+        self.logger = logging.getLogger(
+            '%s.%s' % (__name__, self.__class__.__name__))
         self.udp_sock = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
-        self.logger.debug('Initialized connection to %s:%d with P(%.1f)',
+        self.udp_sock.connect((self._host, self._port))
+        self.logger.debug(
+            'Initialized connection to %s:%d with P(%.1f)',
             self._host, self._port, self._sample_rate)
 
     def send(self, data, sample_rate=None):
@@ -60,8 +66,8 @@ class Connection(object):
         try:
             for stat, value in sampled_data.iteritems():
                 send_data = '%s:%s' % (stat, value)
-                self.udp_sock.sendto(send_data, (self._host, self._port))
-                return True
+                self.udp_sock.send(send_data)
+            return True
         except Exception, e:
             self.logger.exception('unexpected error %r while sending data', e)
             return False
